@@ -12,7 +12,7 @@
 # import re below must be here since we use in an exec statement
 # noinspection PyUnresolvedReferences
 import re
-
+import tempfile
 import os
 import time
 import sysconfig
@@ -30,7 +30,7 @@ from pathlib import Path
 
 from .tf_config_load import update_from_terraform
 from ..Toolbox.json_encoder import extEncoder
-from ..Toolbox.aws_init import post_status_to_cloudwatch, AWS_S3_NAME
+from ..Toolbox.aws_init import S3C, AWS_S3_NAME
 from ..Toolbox.supabase import post_status_to_supabase
 
 try:
@@ -225,9 +225,8 @@ def scantree(inpath, depth=2):
 def merge_all_configs_in_folder(folder, bucket, user_agent=""):
     bootstrap_config_file = os.environ.get("CSI_BOOTSTRAP_CONFIG", '').replace('s3://', '', 1).split('/', 1)[-1]
 
-    s3c = boto3.client("s3")
     try:
-        config_objects = s3c.list_objects_v2(Bucket=bucket, Prefix=folder).get("Contents", [])
+        config_objects = S3C.list_objects_v2(Bucket=bucket, Prefix=folder).get("Contents", [])
     except ClientError as err:
         print(f"[WARNING] Merge-configs: Unable to list objects in bucket '{bucket}': {err}")
         return {}
@@ -236,7 +235,7 @@ def merge_all_configs_in_folder(folder, bucket, user_agent=""):
 
     object_contents = {}
     for key in [k.get('Key', '') for k in config_objects if k.get('Key', False)]:
-        content = s3c.get_object(Bucket=bucket, Key=key).get('Body')
+        content = S3C.get_object(Bucket=bucket, Key=key).get('Body')
         if content is not None and content.readable():
             content = content.read()
             content = content.decode() if not isinstance(content, str) else content
@@ -653,8 +652,7 @@ class Config:
         os.environ['CSI_LOG_LEVEL'] = self.logLevel
         self.testLocal = ('<default>' in self.platform)
 
-        ldd = os.environ.get("CSI_LOCAL_DATA_DIR",
-                             self.D['GLOBAL'].get('localPrefix', f"/tmp/data"))
+        ldd = os.environ.get("CSI_LOCAL_DATA_DIR") or tempfile.mkdtemp()
 
         if not Path(ldd).is_absolute():
             ldd = Path('/tmp').joinpath(Path(ldd))
