@@ -45,7 +45,7 @@ from urllib3.exceptions import NewConnectionError
 from ..Common.init import CFG, post_status_message
 from ..Toolbox.retry import retry
 from ..Toolbox.goodies import first_valid, normalize_host_config, fnfilter_list
-from ..Toolbox.aws_init import boto3, boto3config, AWS, check_s3_name, AWS_S3_NAME
+from ..Toolbox.aws_init import boto3, boto3config, AWS, check_s3_name, AWS_S3_NAME, new_aws_client, S3C
 
 
 # ############# INCLUDE HERE THE NAMES OF TESTED OBJECT STORE TYPES ################ #
@@ -53,8 +53,7 @@ from ..Toolbox.aws_init import boto3, boto3config, AWS, check_s3_name, AWS_S3_NA
 #          CFG.D['Object_Sources'][<host-name>]['type']
 #          CFG.D["Dependencies"]["shared-storage"]["targets"][<host-name>]['type']
 #
-# AWS_S3_NAME = 's3.amazonaws.com'
-SupportedS3likeStoreTypes = [AWS_S3_NAME, 'minio']
+SupportedS3likeStoreTypes = ['minio']
 cs3idp = f"cs3aws"
 # ################################################################################## #
 
@@ -391,12 +390,16 @@ def ropen(*args, **kwargs):
     try:
         ret = smart_open_open(*args, **kwargs)
     except ValueError as err:
+        print(f"[ERROR] args = {args}")
+        print(f"[ERROR] kwargs = {kwargs}")
+
         if str(err).count('ExpiredToken'):
             print(f"[ERROR] Got ValueError->ExpiredToken Exiting")
             post_status_message(stage="4.0", category="warning",
                                 message=f"Expired auth token. Shutting down",
                                 status="red")
-            exit(0)
+            S3C.list_buckets()
+            # exit(0)
 
         print(f"[WARNING] Got ValueError trying to open '{args[0]}': {err}")
         print(f"bucket = {CFG.bucket}")
@@ -490,7 +493,14 @@ def caber_parse_uri(uri_as_string):
         uri_as_string, object_version = uri_as_string.rsplit(CFG.G["objVersSeparator"], 1)
 
     uri_as_string = f"{scheme}{uri_as_string}"
-    transport_params = scfg.get("transport_params", None)
+    transport_params = scfg.get("transport_params") or {}
+
+    print(f"[DEBUG] Remote_Open uri_as_string is: {uri_as_string}")
+    print(f"[DEBUG] Remote_Open scfg is: {scfg}")
+
+    if "client" not in transport_params and scfg.get("client", None) is not None:
+        print(f"[DEBUG] Adding client to transport_params")
+        transport_params.update({"client": scfg["client"]})
 
     if object_version:
         if not transport_params:
@@ -743,9 +753,12 @@ def get_object_store_client(src_config=None):
     if check_s3_name(host_type) == AWS_S3_NAME:
 
         # Creating the client always succeeds so long as the boto3config parameters are of the correct type
-        obst_client = boto3.client('s3', config=adv_config)
+        obst_client = new_aws_client('s3', config=adv_config)
         scfg.update({"client": obst_client})
 
+        if not _test_store_client(scfg, host_type, obst_client):
+            raise ConnectionError(f"Failed to connect to {host_type} host")
+
         for k in set(default_configs[AWS_S3_NAME].keys()).difference(scfg.keys()):
             scfg.update({k: default_configs[AWS_S3_NAME][k]})
 
