@@ -31,7 +31,7 @@ from packaging import version
 
 from .tf_config_load import update_from_terraform
 from .json_encoder import extEncoder
-from .aws_init import post_status_to_cloudwatch, AWS_S3_NAME
+from .aws_init import post_status_to_cloudwatch, AWS_S3_NAME, S3C
 from .supabase import post_status_to_supabase
 
 try:
@@ -221,9 +221,8 @@ def scantree(inpath, depth=2):
 def merge_all_configs_in_folder(folder, bucket, user_agent=""):
     bootstrap_config_file = os.environ.get("CSI_BOOTSTRAP_CONFIG", '').replace('s3://', '', 1).split('/', 1)[-1]
 
-    s3c = boto3.client("s3")
     try:
-        config_objects = s3c.list_objects_v2(Bucket=bucket, Prefix=folder).get("Contents", [])
+        config_objects = S3C.list_objects_v2(Bucket=bucket, Prefix=folder).get("Contents", [])
     except ClientError as err:
         print(f"[WARNING] Merge-configs: Unable to list objects in bucket '{bucket}': {err}")
         return {}
@@ -232,7 +231,7 @@ def merge_all_configs_in_folder(folder, bucket, user_agent=""):
 
     object_contents = {}
     for key in [k.get('Key', '') for k in config_objects if k.get('Key', False)]:
-        content = s3c.get_object(Bucket=bucket, Key=key).get('Body')
+        content = S3C.get_object(Bucket=bucket, Key=key).get('Body')
         if content is not None and content.readable():
             content = content.read()
             content = content.decode() if not isinstance(content, str) else content
